/**
 * @file
 * Dialog initialization for mail preview.
 */

(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.behaviors.externalLinkPopup = {
    attach: function (context) {
      var self = this;
      var settings = drupalSettings.external_link_popup;

      if (
        !settings.popups
        || !settings.popups.length
        || !$('body', context).once('external-link-popup').length
      ) {
        return;
      }

      // RegExp /\s*,\s*|\s+/ supports both space and comma delimiters
      // and its combination.
      var whitelist = settings.whitelist ? settings.whitelist.split(/\s*,\s*|\s+/) : [];
      var current = window.location.host || window.location.hostname;
      var popup;

      whitelist.unshift(current);
      if (current.substr(0, 4) === 'www.') {
        whitelist.push(current.substr(4));
      }
      else {
        whitelist.push('www.' + current);
      }

      // $.once checked above.
      $('body', context).click(function (e) {
        // Use native JS DOM for performance.
        var element = e.target;
        var parent = element.parentNode;
        var level;

        // Look for link in up to 5 parents, limit parents for performance.
        while (parent) {
          level = level ? level + 1 : 0;
          if (parent.tagName === 'A') {
            element = parent;
            break;
          }
          if (level >= 5) {
            break;
          }
          parent = parent.parentNode;
        }

        if (element.tagName !== 'A' || element.classList.contains('external-link-popup-disabled')) {
          return;
        }

        var domain = self.getDomain(element.href);
        if (!domain || self.inDomain(domain, whitelist)) {
          return;
        }

        for (var i = 0; i < settings.popups.length; i++) {
          popup = settings.popups[i];
          if (popup.domains !== '*' && !self.inDomain(domain, popup.domains.split(/\s*,\s*|\s+/))) {
            continue;
          }
          e.preventDefault();
          return self.openDialog(
            element,
            popup,
            'external-link-popup-id-' + popup.id.replace('_', '-')
          );
        }
      });
    },
    inDomain: function (domain, domains) {
      for (var i in domains) {
        if (domain === domains[i] || domain.match(new RegExp(
          '\\.' + this.pregEscape(domains[i]) + '$'
        ))) {
          return true;
        }
      }
      return false;
    },
    getDomain: function (url) {
      var matches = url.match(/\/\/([^/]+)\/?/);
      return matches && matches[1];
    },
    pregEscape: function (str) {
      return (str + '').replace(new RegExp('[.\\\\+*?\\[\\^\\]$(){}=!<>|:\\-]', 'g'), '\\$&');
    },
    openDialog: function (element, settings, className) {
      var dialog;
      var body = document.createElement('div');
      var content = document.createElement('div');
      var options = {
        title: settings.title,
        width: '85%',
        buttons: [
          {
            text: settings.labelyes,
            click: function () {
              $(this).dialog('close');
              var target = window.open(element.href, element.target);
              target.focus();
            }
          }
        ],
        create: function () {
          var $widget = $(this).parent();
          $widget.addClass('external-link-popup').addClass(className);
          if (!settings.close) {
            $widget.find('.ui-dialog-titlebar-close').remove();
          }
          if (!settings.title) {
            $widget.find('.ui-dialog-titlebar').remove();
          }
        },
        close: function () {
          var $element = $(this);
          if (dialog && dialog.open) {
            dialog.close();
          }
          $element.dialog('destroy');
        }
      };
      if (settings.labelno) {
        options.buttons.push({
          text: settings.labelno,
          click: function () {
            $(this).dialog('close');
          }
        });
      }

      content.className = 'external-link-popup-content';
      body.innerHTML = settings.body;
      body.className = 'external-link-popup-body';
      content.appendChild(body);

      dialog = Drupal.dialog(content, options);
      dialog.showModal();
    }
  };
})(jQuery, Drupal, drupalSettings);
